<?php

if(!class_exists('Intense_Post_Type_Templates', false)) {
	class Intense_Post_Type_Templates extends Intense_Post_Type {
		function __construct() {
			add_action( 'save_post', array( __CLASS__, 'save_template_cache' ) );
			$theme = wp_get_theme(); // gets the current theme
			$post_type_label = 'Post Type';

			$post_type_location = array (
				'books' => __( 'Books', 'intense' ),
				'clients' => __( 'Clients', 'intense' ),
				'coupons' => __( 'Coupons', 'intense' ),
				'events' => __( 'Events', 'intense' ),
				'faq' => __( 'FAQ', 'intense' ),
				'jobs' => __( 'Jobs', 'intense' ),
				'locations' => __( 'Locations', 'intense' ),
				'movies' => __( 'Movies', 'intense' ),
				'news' => __( 'News', 'intense' ),
				'portfolio' => __( 'Portfolios', 'intense' ),
				'post' => __( 'Posts', 'intense' ),
				'project' => __( 'Projects', 'intense' ),
				'quotes' => __( 'Quotes', 'intense' ),
				'recipes' => __( 'Recipes', 'intense' ),
				'team' => __( 'Team', 'intense' ),
				'testimonials' => __( 'Testimonials', 'intense' ),
				'wooproduct' => __( 'WooCommerce Product', 'intense' ),
			);

			$post_type_label = apply_filters( 'intense/post_type_template/label', $post_type_label );
			$post_type_location = apply_filters( 'intense/post_type_template/location', $post_type_location );

	    	$this->type = 'intense_templates';
	    	$this->title = 'Enter Template Name';
		    $this->singular = __( 'Template', 'intense' );
		    $this->plural = __( 'Templates', 'intense' );
		    $this->icon = 'dashicons-editor-paste-text';
		    $this->category_taxonomy_key = 'intense_job_category';
		    $this->taxonomies = '';
		    $this->exclude_from_search = true;
		    $this->fields = array(
				array (
					'key' => 'field_536d98898a125',
					'label' => $post_type_label,
					'name' => 'intense_templates_post_type',
					'type' => 'select',
					'required' => 1,
					'choices' => $post_type_location,
					'default_value' => 'intense_post',
					'allow_null' => 0,
					'multiple' => 0,
				),
				array (
					'key' => 'field_536d99bd8a126',
					'label' => 'type',
					'name' => 'intense_templates_type',
					'type' => 'select',
					'instructions' => 'Select \'single\' for single page post template and \'multiple\' for creating a template to display a list of posts.',
					'choices' => array (
						'single' => 'Single',
						'multiple' => 'Multiple',
					),
					'default_value' => 'single',
					'allow_null' => 0,
					'multiple' => 0,
				),
				array (
					'key' => 'field_536d9a658a127',
					'label' => 'Columns',
					'name' => 'intense_templates_columns',
					'type' => 'select',
					'instructions' => 'Select the number of columns you want the template to show when it is used.',
					'conditional_logic' => array (
						'status' => 1,
						'rules' => array (
							array (
								'field' => 'field_536d99bd8a126',
								'operator' => '==',
								'value' => 'multiple',
							),
						),
						'allorany' => 'all',
					),
					'choices' => array (
						'one' => 1,
						'two' => 2,
						'three' => 3,
						'four' => 4,
						'six' => 6,
					),
					'default_value' => '',
					'allow_null' => 1,
					'multiple' => 0,
				),
		    );
			
			include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
			if ( !is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
				unset( $this->fields[0]['choices']['product'] );
			}
		}

		public static function save_all_template_cache() {
			//Loads the saved templates
			$query = new WP_Query( array(
				'post_type' => 'intense_templates',
				'post_status' => 'publish',
				'no_paging' => true,
				'posts_per_page' => -1,					
				'orderby' => 'date',
				'order' => 'ASC'
			) );

			while ( $query->have_posts() ) { $query->the_post();
				global $post;
				
				Intense_Post_Type_Templates::save_template_cache( $post->id );
			}
		}

		/**
		 * Save post metadata when a post is saved.
		 *
		 * @param int $post_id The ID of the post.
		 */
		public static function save_template_cache( $post_id ) {
		    // If this isn't one of our 'templates' posts, don't update it.
		    if ( 'intense_templates' != get_post_type( $post_id ) ) {
		        return;
		    }

		    Intense_Post_Type_Templates::save_as_file( $post_id );
		}

		public static function get_template_cache( $post_id ) {
			$post_type_location = get_post_meta( $post_id, 'intense_templates_post_type', true );			

			if ( $post_type_location == 'secondary_header' ) {				
				$intense_cache_dir = Intense::get_cache_folder( 'secondary_header' );
			} elseif ( $post_type_location == 'title_bar' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'title_bar' );
			} elseif ( $post_type_location == 'primary_footer' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'primary_footer' );
			} elseif ( $post_type_location == 'secondary_footer' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'secondary_footer' );
			} else {
				$intense_cache_dir = Intense::get_cache_folder();
			}

			$cache_file = $intense_cache_dir . 'template_' . $post_id . '.php';

			if ( !file_exists( $cache_file ) ) {
				Intense_Post_Type_Templates::save_as_file( $post_id );
			}

			return $cache_file;
		}

		public static function save_as_file( $post_id ) {
			$post = get_post( $post_id );
			$type =  get_post_meta( $post->ID, 'intense_templates_type', true );
			$post_type_location = get_post_meta( $post->ID, 'intense_templates_post_type', true );
			$template = '';

			switch ( $type ) {
				case 'multiple':
					$template = Intense_Post_Type_Templates::generate_list_template( $post );
					break;			
				case 'single':
					$template = Intense_Post_Type_Templates::generate_single_template( $post );

					$template = apply_filters( 'intense/post_type_template/template', $template, array(
						'post_type_location' => $post_type_location, 
						'post' => $post
					));

					break;
			}

			if ( $post_type_location == 'secondary_header' ) {				
				$intense_cache_dir = Intense::get_cache_folder( 'secondary_header' );
			} elseif ( $post_type_location == 'title_bar' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'title_bar' );
			} elseif ( $post_type_location == 'primary_footer' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'primary_footer' );
			} elseif ( $post_type_location == 'secondary_footer' ) {
				$intense_cache_dir = Intense::get_cache_folder( 'secondary_footer' );
			} else {
				$intense_cache_dir = Intense::get_cache_folder();
			}

			$cache_file = $intense_cache_dir . 'template_' . $post->ID . '.php';

			if ( file_exists( $cache_file ) ) unlink( $cache_file );

			if ( !file_exists( $intense_cache_dir ) ) {
				mkdir( $intense_cache_dir, 0777, true );
			}

			if ( $template != '' ) {
				WP_Filesystem();
				global $wp_filesystem;
				$wp_filesystem->put_contents( $cache_file, $template );
			}
		}

		public static function generate_single_template( $post ){
			$template = "
	        <?php
	        /*
	        Intense Template Name: " . get_the_title( $post->ID ) . "
	        */

	        get_header( 'intense' );
	        " . '$content' . " = <<<TEMPLATE
" .  $post->post_content . "
TEMPLATE;
	        do_action( 'intense_before_main_content' ); 
	        echo do_shortcode(" . '$content' . ");
	        do_action( 'intense_after_main_content' );

	        get_footer( 'intense' );
	      ?>";

	      return $template;
		}

		public static function generate_list_template( $post ) {
			$intense_custom_post = Intense_Custom_Post::get_metadata();
			$columns =  get_post_meta( $post->ID, 'intense_templates_columns', true );

			if ( $columns === 'two' ) {
				$column = '6';
			} elseif ( $columns === 'three' ) {
				$column = '4';
			} elseif ( $columns === 'four') {
				$column = '3';
			} elseif ( $columns === 'six') {
				$column = '2';
			} else {
				$column = '12';
			}

			$template = "<?php
	/*
	Intense Template Name: " . get_the_title( $post->ID ) . "
	*/
	" . '$intense_custom_post = Intense_Custom_Post::get_metadata();' . "
	" . '$classes = $intense_custom_post[\'post_classes\'];' . "
	?>
	<div class='intense col-lg-" . $column . " col-md-" . $column . " col-sm-12 col-xs-12 " . '<?php echo $classes; ?>' . " intense_post' style='margin-left: 0px; padding: 0 10px; padding-bottom: 0px; display:inline-block; vertical-align: top;'>
	<article><?php 
	" . '$content' . " = <<<TEMPLATE
" .  $post->post_content . "
TEMPLATE;
	echo do_shortcode(" . '$content' . ");
	?></article></div>";

			return $template;
		}		
	}
}
