<?php

class Intense_Assets {
	static $added_assets = array(
		'styles' => array(),
		'scripts' => array()
	);

	public static $asset_list = array();

	function __construct() {
		require_once INTENSE_PLUGIN_FOLDER . '/assets/asset-list.php';

		add_action( 'wp_head', array( __CLASS__, 'intense_head' ) );

		add_action( 'wp_head', array( __CLASS__, 'register' ) );
		add_action( 'admin_head', array( __CLASS__, 'register' ) );
		add_action( 'intense/preview/before', array( __CLASS__, 'register' ) );

		add_action( 'wp_footer', array( __CLASS__, 'enqueue' ) );
		add_action( 'admin_footer', array( __CLASS__, 'enqueue' ) );
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue' ) );

		add_action( 'wp_footer', array( __CLASS__, 'intense_footer' ), 1000 );

		add_action( 'intense/preview/after',  array( __CLASS__, 'write' ) );
		add_filter( 'script_loader_tag', array( __CLASS__, 'add_defer_attribute' ), 10, 2);

		if ( is_admin() ) {
			intense_add_style( 'intense.adminicons' );
			intense_add_style( 'intense.admin' );
		}

		Intense_Assets::$asset_list = intense_get_asset_list();
	}	

	public static function add_defer_attribute($tag, $handle) {
		if ( in_array( $handle, array_keys( Intense_Assets::$asset_list['script'] ) ) && !in_array( $handle, Intense_Assets::$asset_list ['no-defer'] ) ) {
			return str_replace( ' src', ' async="async" src', $tag );
		} else {
			return $tag;
		}
	}

	public static function enqueue() {
		Intense_Assets::enqueue_style();
		Intense_Assets::enqueue_script();
	}

	/**
	 * Enqueue assets
	 */
	public static function enqueue_script() {
		$assets = self::added_assets();

		intense_add_script( 'intense_modernizr' );

		require_once INTENSE_PLUGIN_FOLDER . '/assets/asset-list.php';

		foreach ( $assets['scripts'] as $script ) {
			intense_register_asset( Intense_Assets::$asset_list, 'script', $script );
			wp_enqueue_script( $script );
		}

		self::inline_js();

		do_action( 'intense/assets/enqueue', $assets );
	}

	public static function enqueue_style() {
		$assets = self::added_assets();

		intense_add_style( 'intense-custom-css' );

		require_once INTENSE_PLUGIN_FOLDER . '/assets/asset-list.php';

		foreach ( $assets['styles'] as $style ) {
			intense_register_asset( Intense_Assets::$asset_list, 'style', $style );
			wp_enqueue_style( $style );
		}

		self::inline_css();
		self::inline_svg();	
		
		do_action( 'intense/assets/enqueue', $assets );
	}

	/**
	 * Write assets to page
	 */
	public static function write() {
		$assets = self::added_assets();

		intense_add_style( 'intense-custom-css' );
		intense_add_script( 'intense_modernizr' );

		wp_print_styles( $assets['styles'] );
		wp_print_scripts( $assets['scripts'] );

		self::inline_css();
		self::inline_js();
		self::inline_svg();

		do_action( 'intense/assets/write', $assets );
	}

	/**
	 * Dumps inline css
	 */
	public static function inline_css() {
		if ( isset( Intense()->dynamic_css ) ) {
			echo "<style>";
			echo "
			        /* shortcode styles */
			";

			foreach ( Intense()->dynamic_css as $key => $value ) {
				echo $value . "\n";
			}

			echo "</style>";
		}
	}

	/**
	 * Dumps inline js
	 */
	public static function inline_js() {
		if ( isset( Intense()->dynamic_js ) ) {
			echo "<script>";
			echo "
			        /* shortcode scripts */
			";

			foreach ( Intense()->dynamic_js as $key => $value ) {
				echo $value . "\n";
			}

			echo "</script>";
		}
	}

	public static function inline_svg() {
		if ( isset( Intense()->dynamic_svg ) ) {
			echo '<svg xmlns="http://www.w3.org/2000/svg" style="display: none;">';
			echo "
			        <!-- shortcode svg -->
			";

			foreach ( Intense()->dynamic_svg as $key => $value ) {
				echo $value . "\n";
			}

			echo "</svg>";
		}
	}	

	/**
	 * Registers the scripts and styles for enqueueing and writing
	 */
	public static function register() {
		$css_key = Intense_Assets::get_intense_css_key();
		$hashed_filename = 'intense_' . $css_key . '.css';
		$intense_cache_dir = Intense::get_cache_folder( 'css' );
		$intense_cache_url = Intense::get_cache_url( 'css' );		

		if ( !file_exists( $intense_cache_dir . $hashed_filename ) ) {
			Intense_Assets::set_intense_css( $css_key );
		}

		wp_register_style( 'intense-custom-css', $intense_cache_url . $hashed_filename, null, INTENSE_PLUGIN_VERSION );

		if ( !is_admin() ) {
			wp_enqueue_style('intense-custom-css');
		}

		do_action( 'intense/assets/register' );
	}

	public static function intense_head() {

		// Old browser check
		echo '<!--[if lt IE 7]> <meta id="intense-browser-check" class="no-js ie6 oldie"> <![endif]-->
		        <!--[if IE 7]> <meta id="intense-browser-check" class="no-js ie7 oldie"> <![endif]-->
		        <!--[if IE 8]> <meta id="intense-browser-check" class="no-js ie8 oldie"> <![endif]-->
		        <!--[if IE 9]> <meta id="intense-browser-check" class="no-js ie9 oldie"> <![endif]-->
		        <!--[if gt IE 9]><!--> <meta id="intense-browser-check" class="no-js"> <!--<![endif]-->';

		// HTML5 Shiv
		if ( isset( Intense()->options['intense_html5_shiv'] ) && Intense()->options['intense_html5_shiv'] == 1 ) {
			echo '<!--[if lt IE 9]><script src="' . INTENSE_PLUGIN_URL . '/assets/js/html5shiv/dist/html5shiv.js' . '"></script><![endif]-->';
		}

		echo "<style type='text/css'>";

		echo ".intense.pagination .active > a { \n  background-color: " . intense_get_plugin_color( 'primary' ) . "; \n  border-color: " . intense_adjust_color_brightness( intense_get_plugin_color( 'primary' ), -30 ) . "; \n  color: " . intense_get_contrast_color( intense_get_plugin_color( 'primary' ) ) . ";  } ";

		// Custom CSS
		if ( isset( Intense()->options['intense_custom_css'] ) ) {
			echo "\n/* custom css styles */\n" . Intense()->options['intense_custom_css'] . "\n";
		}

		echo "\n</style>";

		echo '<!--[if lt IE 9]><script src="' . INTENSE_PLUGIN_URL . '/assets/js/respond/dest/respond.min.js' . '"></script><![endif]-->';

		if ( !empty( Intense()->options['intense_head_code'] ) ) {
			echo Intense()->options['intense_head_code'];
		}
	}

	public static function intense_footer() {
		$user = wp_get_current_user();
		$tracking_roles = isset( Intense()->options['intense_tracking_roles'] ) ? Intense()->options['intense_tracking_roles'] : null;
		$user_role = reset($user->roles);
		$show_tracking_code = 1;

		if ( !empty( $user_role ) && isset( $tracking_roles ) && is_array( $tracking_roles ) && array_key_exists( $user_role, $tracking_roles ) && !empty( $tracking_roles[$user_role] ) ) {            
		    $show_tracking_code = 0;
		}

		if ( !empty( Intense()->options['intense_body_code'] ) ) {
			echo Intense()->options['intense_body_code'];
		}

		if ( $show_tracking_code && !empty( Intense()->options['intense_tracking_code'] ) ) {
			echo Intense()->options['intense_tracking_code'];
		}
	}

	/**
	 * Adds an asset to the list of used assets
	 */
	public static function add( $type, $handle ) {
		if ( is_array( $handle ) ) {
			foreach ( $handle as $h )
				self::add( $type, $h );
		} else {
			self::$added_assets[ $type ][ $handle ] = $handle;
		}
	}

	public static function get_intense_css_files() {

		//if ( false === ( $files = wp_cache_get( 'get_intense_css_files' ) ) ) {			
			$shortcode_css = Intense_Shortcodes::get_shortcode_css_paths();

			if ( isset( Intense()->options['intense_shortcode_css']['shadow'] ) && Intense()->options['intense_shortcode_css']['shadow'] == 1 ) {
				$files = array( 'shadow' => INTENSE_PLUGIN_FOLDER . '/assets/css/intense/shadow.min.css' );
			} else {
				$files = array();
			}

			foreach ($shortcode_css as $key => $css_files) {
				if ( isset( Intense()->options['intense_shortcode_css'][ $key ] ) && Intense()->options['intense_shortcode_css'][ $key ] == 1 ) {
					$files = array_merge( $files, $css_files );
				}
			}

			$files = array_unique( $files );

		//	wp_cache_set( 'get_intense_css_files', $files);
		//}

		return $files;
	}

	/**
	 * Gets a key used for dynamic intense css file
	 *
	 * @return string key
	 */
	public static function get_intense_css_key() {
		$enabled_styles = filemtime( INTENSE_PLUGIN_FOLDER . '/assets/css/intense/intense.min.css' ) . '|';

		$files = Intense_Assets::get_intense_css_files();

		foreach ( $files as $key => $value ) {
			$enabled_styles .= filemtime( $value ) . '|';
		}

		return hash( 'sha1', $enabled_styles . INTENSE_PLUGIN_VERSION );
	}

	/**
	 * Creates the dynamic css file
	 */
	public static function set_intense_css( $css_key ) {
		WP_Filesystem();
		global $wp_filesystem;
	
		$intense_cache_dir = Intense::get_cache_folder( 'css' );

		$files = Intense_Assets::get_intense_css_files();

		if ( !class_exists( 'scssc' ) ) {
			require_once INTENSE_PLUGIN_FOLDER . '/inc/libraries/scssphp/scss.inc.php';
		}

		$scss = new scssc();

    	$scss->setImportPaths( INTENSE_PLUGIN_FOLDER . '/assets/sass/intense/' );

        if (!INTENSE_DEBUG) {
            $scss->setFormatter( "scss_formatter_compressed" );
        } else {
        	$scss->setFormatter( 'scss_formatter' );
        }

        $css = '';
        $css .= $scss->compile( $wp_filesystem->get_contents( INTENSE_PLUGIN_FOLDER . '/assets/sass/intense/intense.scss' ) );
        
		foreach ( $files as $key => $value ) {	
			$shortcode_filename = basename( $value );
			$css_filename = str_replace( ".scss", ".css", $shortcode_filename );			

			$individual_css = $scss->compile( $wp_filesystem->get_contents( $value ) );
			
			if ( false === $wp_filesystem->put_contents( $intense_cache_dir . $css_filename, $individual_css ) ) {				
				echo "Oh, no! There were issues creating dynamic CSS for Intense. Check your permissions on the following folder to make sure it is writable: " . $intense_cache_dir;
				die();
			}

			$css .= $individual_css;
		}

		$hashed_filename = 'intense_' . $css_key . '.css';		

		if ( !file_exists( $intense_cache_dir . $hashed_filename ) ) {
			$URL_without_protocol = str_replace( "http://", "//", INTENSE_PLUGIN_URL );
			$URL_without_protocol = str_replace( "https://", "//", $URL_without_protocol );

			$css = str_replace( "[intense_assets_path]", $URL_without_protocol . "/assets" , $css );			
			$css = str_replace( ': ', ':', $css );

			if ( false === $wp_filesystem->put_contents( $intense_cache_dir . $hashed_filename, $css ) ) {
				echo "Oh, no! There were issues creating dynamic CSS for Intense. Check your permissions on the following folder to make sure it is writable: " . $intense_cache_dir;
				die();
			}
		}
	}

	/**
	 * Get added assets
	 */
	public static function added_assets() {
		$assets = self::$added_assets;

		// Make unique and apply filter
		$assets['styles'] = array_unique( ( array ) apply_filters( 'intense/assets/css', ( array ) array_unique( $assets['styles'] ) ) );
		$assets['scripts'] = array_unique( ( array ) apply_filters( 'intense/assets/js', ( array ) array_unique( $assets['scripts'] ) ) );

		return $assets;
	}
}

function intense_register_asset( $assets, $type, $handle ) {
	if ( !empty( $assets[ $type ][ $handle ] ) ) {
		$asset = $assets[ $type ][ $handle ];
	
		switch ( $type ) {
			case 'style':
				if ( ! wp_style_is( $handle, 'registered') ) {
					call_user_func_array( 'wp_register_style', $asset );
				}
				break;		
			case 'script':
				if ( ! wp_script_is( $handle, 'registered') ) {
					call_user_func_array( 'wp_register_script', $asset );
				}

				if ( !empty( $assets[ 'localize' ][ $handle ] ) ) {
					call_user_func_array( 'wp_localize_script', $assets[ 'localize' ][ $handle ] );
				}

				break;
		}
	}
}

function intense_register_all_assets() {
	require_once INTENSE_PLUGIN_FOLDER . '/assets/asset-list.php';

	foreach ( Intense_Assets::$asset_list['style'] as $key => $value ) {
		intense_register_asset( Intense_Assets::$asset_list, 'style', $key );
	}

	foreach ( Intense_Assets::$asset_list['script'] as $key => $value ) {
		intense_register_asset( Intense_Assets::$asset_list, 'script', $key );
	}
}

/**
 * Helper function for adding scripts
 *
 * @param string/array $handle the script handle or array of script handles to add
 */
function intense_add_script( $handle ) {
	Intense_Assets::add( 'scripts', $handle );
}

/**
 * Helper function for adding styles
 * @param string/array $handle the style handle or array of style handles to add
 */
function intense_add_style( $handle ) {	
	if ( is_admin() ) {
		Intense_Assets::add( 'styles', $handle );
	} else {
		require_once INTENSE_PLUGIN_FOLDER . '/assets/asset-list.php';

		intense_register_asset( Intense_Assets::$asset_list, 'style', $handle );	
		// load the css inline to prevent janky loading 
		// only if the style has been registered and hasn’t been printed yet.
		// see http://www.peterrknight.com/loading-css-mid-page-html5-wordpress-passing-validation-part-2/
		if ( wp_style_is( $handle, 'registered') && ! wp_style_is( $handle, 'done' ) ) {
			global $wp_styles;
			
			add_filter( 'style_loader_tag', 'intense_html5_inline_stylesheet', 10, 2 );
			$print = $wp_styles->do_item( $handle );

			// set this style to ‘done’ status
			$wp_styles->done[] = $handle;

			// remove from to do just in case the style was invoked elsewhere for the footer
			$to_do = $wp_styles ->to_do;
			if ( is_array( $to_do ) ) {
				foreach( $to_do as $key => $to_do_handle ) {
					if( $to_do_handle == $handle ) {
						unset( $wp_styles->to_do[$key] );
					}
				}
			}			
		}
	}
}

// see http://www.peterrknight.com/loading-css-mid-page-html5-wordpress-passing-validation-part-2/
function intense_html5_inline_stylesheet( $output ) {	
	echo $output;

	//$url = preg_match("/(href=')(.+)(' type)/", $output, $styleurl);

	$output = '
	';

	return $output;
}

function intense_load_subtle_effect_CSS( $type ) {
	WP_Filesystem();
	global $wp_filesystem;

	$minified = ( INTENSE_DEBUG ? "" : "min." );

	if ( isset( $type ) ) {
		$css = "";
		$css = $wp_filesystem->get_contents( INTENSE_PLUGIN_FOLDER . '/assets/css/subtle/subtle-' . $type . '.' . $minified . 'css' );

		Intense()->add_dynamic_css( 'subtle_' . $type, $css );

		intense_add_style( 'subtle-effect' );
	}
}
