<?php

class Intense_Map extends Intense_Shortcode {

    function __construct() {
        parent::__construct();

        $this->title = __( 'Map', 'intense' );
        $this->description = __( 'The map shortcode allows you to include a Google map on your page. There are a number of options to choose from when creating your map. There are color options, marker options and different layers that can be added to your map.', 'intense' );
        $this->category = __( 'Media', 'intense' );
        //$this->show_preview = true;
        $this->is_container = true;
    }

    function shortcode( $atts, $content = null ) {
        extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

        //google maps api and styled marker
        intense_add_script( 'googlemap' );
        intense_add_script( 'styledmarker' );

        $output = '';
        $random = ( !empty ( $id ) ) ? $id : rand();
        $GLOBALS['map_number'] = $random;
        $mapID = ( !empty ( $id ) ) ? $id : 'map_' . $random;
        $mapFunction = 'Map' . $random;
        $shadow_style = "margin-bottom: 0;";
        $GLOBALS['fit_bounds'] = $fit_bounds;
        $GLOBALS['show_routes'] = 0;
        $stylers = '';
        $styler_options = '';

        if ( isset( $hue ) || isset( $saturation ) || isset( $lightness ) || isset( $gamma ) || $lightness_invert != 0 ) {
            if ( isset( $hue ) ) {
                $styler_options .= "          { 'hue': '" . $hue . "' },";
            }

            if ( isset( $saturation ) ) {
                $styler_options .= "          { 'saturation': '" . $saturation . "' },";
            }

            if ( isset( $lightness ) ) {
                $styler_options .= "          { 'lightness': '" . $lightness . "' },";
            }

            if ( isset( $gamma ) ) {
                $styler_options .= "          { 'gamma': '" . $gamma . "' },";
            }

            if ( $lightness_invert != 0 ) {
                $styler_options .= "          { 'invert_lightness': true },";
            }

            $styler_options = substr($styler_options, 0, -1);
        }

        $output = '';

        if ( $shadow ) {
            $output .= "<div><div style='$shadow_style'>";
        }

        if ( is_numeric( $width ) ) {
            $width .= 'px';
        }

        if ( is_numeric( $height ) ) {
            $height .= 'px';
        }

        $output .= "<div id='" . $mapID . "' class='mapcanvas" . ( !empty( $class ) ? ' ' . esc_attr( $class ) : '' ) . "' style='width: " . $width . "; height: " . $height . "; direction: ltr;'></div>";

        if ( $shadow ) {
            $output .= "</div><img src='" . INTENSE_PLUGIN_URL . "/assets/img/shadow{$shadow}.png' class='intense shadow' style='" . ( isset( $width ) ? 'width: ' . $width . '; height: auto;' : '' ) . "vertical-align: top; border:0px; border-radius: 0px; box-shadow: 0 0 0;' alt='' /></div>";
        }

        $output .= "<script type='text/javascript'>";

        if ( !empty( $styler_options ) ) {
            $output .= "      var styles" . $random . " = [";
            $output .= "        {";
            $output .= "          stylers: [";
            $output .= $styler_options;
            $output .= "          ]";
            $output .= "        }";
            $output .= "      ];";
        }

        $output .= "  function " . $mapFunction . "() {";
        $output .= "    latitude" . $random . " = '';";
        $output .= "    longitude" . $random . " = '';";
        $output .= "    var mapOptions" . $random . " = {";
        $output .= "      zoom: " . $zoom . ",";
        $output .= "      scrollwheel: " . ( $scroll_wheel ? 'true' : 'false' ) . ",";
        $output .= "      draggable: " . ( $is_draggable ? 'true' : 'false' ) . ",";
        $output .= "      scaleControl: " . ( $scale_control ? 'true' : 'false' ) . ",";
        $output .= "      streetViewControl: " . ( $street_view ? 'true' : 'false' ) . ",";
        $output .= "      overviewMapControl: " . ( $overview_map ? 'true' : 'false' ) . ",";
        $output .= "      panControl: " . ( $pan_control ? 'true' : 'false' ) . ",";
        $output .= "      mapTypeControl: " . ( $map_type_control ? 'true' : 'false' ) . ",";
        $output .= "      mapTypeControlOptions: {";
        $output .= "        style: google.maps.MapTypeControlStyle." . strtoupper( $map_type_style );
        $output .= "      },";
        $output .= "      zoomControl: " . ( $zoom_control ? "true" : 'false' ) . ",";
        $output .= "      zoomControlOptions: {";
        $output .= "        style: google.maps.ZoomControlStyle." . strtoupper( $zoom_control_style );
        $output .= "      },";
        $output .= "      mapTypeId: google.maps.MapTypeId." . strtoupper( $type ) . ",";
        $output .= "    };";
        $output .= "    var map" . $random . " = new google.maps.Map(document.getElementById('" . $mapID . "'), mapOptions" . $random . ");";

        if ( !empty( $styler_options ) ) {
            $output .= "map" . $random . ".setOptions({styles: styles" . $random . "});";
        }

        $output .= "    var bounds" . $random . " = new google.maps.LatLngBounds();";

        if ( !empty( $latitude ) && !empty( $longitude ) ) {
            $output .= '    map' . $random . '.setCenter(new google.maps.LatLng(' . $latitude . ', ' . $longitude . '));';
        }

        if ( !empty( $address ) ) {
            $output .= 'var geocoder' . $random . ' = new google.maps.Geocoder();';
            $output .= 'geocoder' . $random . '.geocode({ "address": "' . $address . '" }, function (results, status) {';
            $output .= '  if (status == google.maps.GeocoderStatus.OK) {';
            $output .= '    map' . $random . '.setCenter(new google.maps.LatLng(results[0].geometry.location.lat(), results[0].geometry.location.lng()));';
            $output .= '  }';
            $output .= '});';
        }

        if ( $show_routes ) {
            $GLOBALS['fit_bounds'] = 1;
            $GLOBALS['show_routes'] = 1;
            $output .= "    var directionsService" . $random . " = new google.maps.DirectionsService;";
            $output .= "    var directionsDisplay" . $random . " = new google.maps.DirectionsRenderer({ map:map" . $random . ", suppressMarkers: true });";
            $output .= "    var waypts" . $random . " = [];";
            $output .= "    var detailpts" . $random . " = [];";

            if ( $route_color != '' ) {
                $output .= "    directionsDisplay" . $random . ".setOptions({ polylineOptions: { strokeColor: '" . $route_color . "', strokeOpacity: 0.5, strokeWeight: 5 } });";
            }

            if ( !empty( $address_start ) ) {
                $add_start = '[intense_map_marker address="' . $address_start . '" title="' . $address_start_title . '" description="' . $address_start_description . '" markertype="' . ( !empty( $address_start_markertype ) ? $address_start_markertype : 'MARKER' ) . '" color="' . ( !empty( $address_start_color ) ? $address_start_color : Intense()->options['intense_icon_color'] ) . '" ' . ( !empty( $address_start_icontype ) ? 'iconsource="' . $address_start_iconsource . '" icontype="' . $address_start_icontype . '"' : '' ) . ( !empty( $address_start_markerimage ) ? ' markerimage="' . $address_start_markerimage . '"' : '' ) . ( !empty( $address_start_markeranchor ) ? ' markeranchor="' . $address_start_markeranchor . '"' : '' ) . ' markerwaypoint="no"]';
                $output .= do_shortcode( $add_start );   
            }
        }

        $output .= do_shortcode( $content );

        if ( $show_routes ) {
            if ( !empty( $address_start ) && !empty( $address_end ) && $address_start != $address_end ) {
                $add_end = '[intense_map_marker address="' . $address_end . '" title="' . $address_end_title . '" description="' . $address_end_description . '" markertype="' . ( !empty( $address_end_markertype ) ? $address_end_markertype : 'MARKER' ) . '" color="' . ( !empty( $address_end_color ) ? $address_end_color : Intense()->options['intense_icon_color'] ) . '" ' . ( !empty( $address_end_icontype ) ? 'iconsource="' . $address_end_iconsource . '" icontype="' . $address_end_icontype . '"' : '' ) . ( !$make_round_trip ? ' markerwaypoint="no"' : '' ) . ( !empty( $address_end_markerimage ) ? ' markerimage="' . $address_end_markerimage . '"' : '' ) . ( !empty( $address_end_markeranchor ) ? ' markeranchor="' . $address_end_markeranchor . '"' : '' ) . '"]';
                $output .= do_shortcode( $add_end );

                if ( $make_round_trip ) {
                    $address_end = $address_start;
                }
            }

            $output .= "    directionsService" . $random . ".route({";
            $output .= "        origin: '" . $address_start . "',";
            $output .= "        destination: '" . $address_end . "',";
            $output .= "        waypoints: waypts" . $random . ",";
            $output .= "        optimizeWaypoints: " . ( $best_route ? 'true' : 'false' ) . ",";

            if ( $avoid_tolls ) {
                $output .= "        avoidTolls: true,";
            }

            if ( $avoid_highways ) {
                $output .= "        avoidHighways: true,";
            }

            $output .= "        travelMode: '" . ( !empty( $travel_mode ) ? $travel_mode : 'DRIVING' ) . "'";
            $output .= "    }, function(response, status) {";
            $output .= "        if (status === 'OK') {";
            $output .= "            directionsDisplay" . $random . ".setDirections(response);";
            $output .= "            var route" . $random . " = response.routes[0];";

            if ( !$hide_directions ) {
                $output .= "            var summaryPanel" . $random . " = document.getElementById('intense_map_directions" . $random . "');";
                $output .= "            summaryPanel" . $random . ".innerHTML = '';";
                $output .= "            for (var i = 0; i < route" . $random . ".legs.length; i++) {";
                $output .= "                var routeSegment" . $random . " = i + 1;";
                $output .= "                var routeid = route" . $random . ".waypoint_order[i];";
                $output .= "                summaryPanel" . $random . ".innerHTML += '<h3 class=\"intense directions_step_title\" style=\"margin-bottom:10px;\">" . $segment_title . ": ' + routeSegment" . $random . " + '</h3>';";
                $output .= "                summaryPanel" . $random . ".innerHTML += '<div class=\"intense row map-route-overview\" style=\"font-size:14px;\"><div class=\"intense col-lg-9 col-xs-12 col-sm-9 col-md-9\">' + route" . $random . ".legs[i].start_address + ' to ' + route" . $random . ".legs[i].end_address + '</div><div class=\"intense col-lg-3 col-xs-12 col-sm-3 col-md-3\"><div style=\"float:right;\">' + route" . $random . ".legs[i].distance.text + '</div><div style=\"clear:both;\"></div></div></div>';";
                $output .= "                if ( routeid !== 'undefined' && routeSegment" . $random . " < route" . $random . ".legs.length  ) {";
                $output .= "                    var routetitle = detailpts" . $random . "[routeid].title;";
                $output .= "                    var routedescription = detailpts" . $random . "[routeid].description;";
                $output .= "                    var routecolor = detailpts" . $random . "[routeid].color;";
                $output .= "                    var routedesc = '';";
                $output .= "                    routedesc += '<div class=\"map-route-description\">';";
                $output .= "                    if (routetitle != '') {";
                $output .= "                        routedesc += '<strong>' + routetitle + '</strong>';";
                $output .= "                    }";
                $output .= "                    if (routetitle != '' && routedescription != '') {";
                $output .= "                        routedesc += ' - ';";
                $output .= "                    }";
                $output .= "                    if (routedescription != '') {";
                $output .= "                        routedesc += routedescription;";
                $output .= "                    }";
                $output .= "                    routedesc += '</div>';";
                $output .= "                    summaryPanel" . $random . ".innerHTML += routedesc;";
                $output .= "                    summaryPanel" . $random . ".innerHTML += '<hr class=\"intense directions-step-hr\" />';";
                $output .= "                }";

                if ( !$hide_segment_directions ) {
                    $output .= "                for (var j = 0; j < route" . $random . ".legs[i].steps.length; j++) {";
                    $output .= "                    var routeStep" . $random . " = j + 1;";
                    $output .= "                    summaryPanel" . $random . ".innerHTML += '<div class=\"intense row map-routes\" style=\"font-size:13px;\"><div class=\"intense col-lg-9 col-xs-12 col-sm-9 col-md-9\"><div class=\"intense map-directions\"><div class=\"intense-map-maneuver intense-map-' + route" . $random . ".legs[i].steps[j].maneuver + '\"></div></div><div class=\"intense map-instructions\">' + routeStep" . $random . " + '. ' + route" . $random . ".legs[i].steps[j].instructions + '</div></div><div class=\"intense col-lg-3 col-xs-12 col-sm-3 col-md-3\"><div style=\"float:right;\">' + route" . $random . ".legs[i].steps[j].distance.text + '</div><div style=\"clear:both;\"></div></div></div>';";
                    $output .= "                }";
                }

                $output .= "            }";
            }

            $output .= "        }";
            $output .= "    });";
        }

        if ( $traffic_layer != 0 ) {
            $output .= "    var trafficLayer" . $random . " = new google.maps.TrafficLayer();";
            $output .= "    trafficLayer" . $random . ".setMap(map" . $random . ");";
        }

        if ( $transit_layer != 0 ) {
            $output .= "    var transitLayer" . $random . " = new google.maps.TransitLayer();";
            $output .= "    transitLayer" . $random . ".setMap(map" . $random . ");";
        }

        if ( $bicycle_layer != 0 ) {
            $output .= "    var bicycleLayer" . $random . " = new google.maps.BicyclingLayer();";
            $output .= "    bicycleLayer" . $random . ".setMap(map" . $random . ");";
        }

        $output .= "  }";

        $output .= "  function toggleBounce(markerId) {";
        $output .= "    var tmarker = eval('marker' + markerId);";
        $output .= "    if (tmarker.getAnimation() != null) {";
        $output .= "      tmarker.setAnimation(null);";
        $output .= "    } else {";
        $output .= "      tmarker.setAnimation(google.maps.Animation.BOUNCE);";
        $output .= "    }";
        $output .= "  }";
        $output .= "</script>";

        $output .= "<script>  jQuery(function($){";
        $output .= " $(document).ready(function() {";
        $output .= "    google.maps.event.addDomListener(window, 'load', " . $mapFunction . ");";
        $output .= " });";
        $output .= "}); </script>";

        if ( $show_routes ) {
            $output .= "<div class='intense row'><div class='intense col-lg-12 col-xs-12 col-sm-12 col-md-12' id='intense_map_directions" . $random . "'></div></div>";
        }

        return $output;
    }    
}
