<?php

class Intense_Overlay extends Intense_Shortcode {

	function __construct() {
		parent::__construct();

		$this->title = __( 'Overlay', 'intense' );
		$this->description = __( 'The overlay shortcode is used to add an overlay that will show when the user hovers over the image. You can add your own content to show as part of the overlay. Some examples of content you could add include: icons, buttons, text, etc.', 'intense' );
		$this->category = __( 'Layout', 'intense' );
		$this->show_preview = false;
		$this->vc_map_content = 'textarea';
		$this->is_container = true;
	}

	function shortcode( $atts, $content = null ) {

		extract( shortcode_atts( $this->get_shortcode_defaults( null, $atts ), $atts ) );

		$output = '';

		$id = ( !empty ( $id ) ) ? ' id="' . esc_attr( $id ) . '"' : '';

		$subtleheight = '';

		if ( !empty( $subtleeffect ) ) {
			intense_load_subtle_effect_CSS( $subtleeffect );
			intense_add_script( 'intense.subtle.effect' );
		}

		if ( !empty( $split_title ) ) {
			$split_title = explode( ' ', $title, 3 );
		} else {
			$split_title = array();
			$split_title[0] = $title;
		}

		if ( is_numeric( $link ) ) {
			$link = get_permalink( $link );
		}

		if ( !empty( $image ) ) {
			$alt = get_post_meta( $image, '_wp_attachment_image_alt', true );
			if ( count( $alt ) ) {
				$atts['alt'] =  $alt;
			}
		}

		if ( !empty( $font_family ) && FALSE !== strpos( $font_family, 'google|' ) ) {
    		$font_family = str_replace( 'google|', '', $font_family );

    		if ( empty( $GLOBALS['IntenseGoogleFonts'][ $font_family ] ) ) {
	    		$GLOBALS['IntenseGoogleFonts'][ $font_family ] = $font_family;

	    		$link = intense_create_google_font_link( array( $font_family => array() ) );

	    		$output .= '<link href="' . esc_url( $link ) . '" rel="stylesheet" type="text/css">';
	    	}
		}

		if ( is_numeric( $font_size ) ) $font_size .= "px";
		$font_size = ( !empty( $font_size ) ? " font-size: " . $font_size . ';' : '' );
		$font_color = ( !empty( $font_color ) ? " color: " . $font_color . ';' : '' );
		$font_family = ( !empty( $font_family ) ? " font-family: " . $font_family . ';' : '' );

		$atts['class'] = 'subtle-effect-img';
		if ( !empty( $atts['image_size'] ) ) $atts['size'] = $atts['image_size'];
		//$atts['lazy_load'] = "0";

		$image_shortcode = intense_run_shortcode( 'intense_image', $atts );

		if ( !empty( $link ) ) $output .= '<a href="' . $link . '">';

		$output .= '<div class="intense overlay subtle-effect' . ( !empty( $class ) ? ' ' . esc_attr( $class ) : '' ) . '">';
		$output .= "<figure class='intense effect-" . $subtleeffect . "' style='" . ( !empty( $subtleheight ) ? $subtleheight . ';' : '' ) . ( !empty( $link ) ? 'cursor:pointer;' : 'cursor: default;' ) . "'>";
		$output .= $image_shortcode;
		$output .= '<figcaption class="subtle-effect-caption">';
		$output .= '<h2 style="' . $font_color . $font_size . $font_family . '">' . ( !empty( $split_title[0] ) ? esc_html( $split_title[0] ) : '' ) . "<span>" . ( !empty( $split_title[1] ) ? ' ' . esc_html( $split_title[1] ) : '' ) . "</span>" . ( !empty( $split_title[2] ) ? ' ' . esc_html( $split_title[2] ) : '' ) . '</h2>';
		$output .= '<p>';
		$output .= do_shortcode( $content );
		$output .= '</p>';
		$output .= '</figcaption>';
		$output .= '</figure>';
		$output .= '</div>';

		if ( !empty( $link ) ) $output .= '</a>';

		return $output;
	}
}
